==> haskell-conduit-1.3.6.1-86-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 conduit
version:              1.3.6.1
visibility:           public
id:                   conduit-1.3.6.1-JOByYHd4UhSLHkAURX473h
key:                  conduit-1.3.6.1-JOByYHd4UhSLHkAURX473h
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             http://github.com/snoyberg/conduit
synopsis:             Streaming data processing library.
description:
    `conduit` is a solution to the streaming data problem, allowing for production,
    transformation, and consumption of streams of data in constant memory. It is an
    alternative to lazy I\/O which guarantees deterministic resource handling.

    For more information about conduit in general, and how this package in
    particular fits into the ecosystem, see [the conduit
    homepage](https://github.com/snoyberg/conduit#readme).

    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/conduit>.

category:             Data, Conduit
abi:                  cd457bb890dc21bf8198e23ac2cc2d79
exposed:              True
exposed-modules:
    Conduit Data.Conduit Data.Conduit.Combinators
    Data.Conduit.Combinators.Stream Data.Conduit.Internal
    Data.Conduit.Internal.Fusion Data.Conduit.Internal.List.Stream
    Data.Conduit.Lift Data.Conduit.List

hidden-modules:
    Data.Conduit.Internal.Pipe Data.Conduit.Internal.Conduit
    Data.Conduit.Combinators.Unqualified Data.Streaming.FileRead
    Data.Streaming.Filesystem

import-dirs:          /usr/lib/ghc-9.4.8/site-local/conduit-1.3.6.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/conduit-1.3.6.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/conduit-1.3.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-conduit
hs-libraries:         HSconduit-1.3.6.1-JOByYHd4UhSLHkAURX473h
depends:
    base-4.17.2.1 bytestring-0.11.5.3 directory-1.3.7.1
    exceptions-0.10.5 filepath-1.4.2.2
    mono-traversable-1.0.21.0-CsC798l0j1x1KADxlJxEMY mtl-2.2.2
    primitive-0.9.1.0-3zmpEdmoBvMCFbJpHhp8DL
    resourcet-1.2.6-EBGYfS72ufv4niGJn1xKwD text-2.0.2
    transformers-0.5.6.2 unix-2.7.3
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    vector-0.13.2.0-CUNHeeGRzA0LijhekAuhMC

haddock-interfaces:   /usr/share/doc/haskell-conduit/html/conduit.haddock
haddock-html:         /usr/share/doc/haskell-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-conduit-1.3.6.1-87-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 conduit
version:              1.3.6.1
visibility:           public
id:                   conduit-1.3.6.1-8EwOhhDv3r5EX0bCaWMPRW
key:                  conduit-1.3.6.1-8EwOhhDv3r5EX0bCaWMPRW
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             http://github.com/snoyberg/conduit
synopsis:             Streaming data processing library.
description:
    `conduit` is a solution to the streaming data problem, allowing for production,
    transformation, and consumption of streams of data in constant memory. It is an
    alternative to lazy I\/O which guarantees deterministic resource handling.

    For more information about conduit in general, and how this package in
    particular fits into the ecosystem, see [the conduit
    homepage](https://github.com/snoyberg/conduit#readme).

    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/conduit>.

category:             Data, Conduit
abi:                  bd5515e5a9022de794bf0556bee17147
exposed:              True
exposed-modules:
    Conduit Data.Conduit Data.Conduit.Combinators
    Data.Conduit.Combinators.Stream Data.Conduit.Internal
    Data.Conduit.Internal.Fusion Data.Conduit.Internal.List.Stream
    Data.Conduit.Lift Data.Conduit.List

hidden-modules:
    Data.Conduit.Internal.Pipe Data.Conduit.Internal.Conduit
    Data.Conduit.Combinators.Unqualified Data.Streaming.FileRead
    Data.Streaming.Filesystem

import-dirs:          /usr/lib/ghc-9.4.8/site-local/conduit-1.3.6.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/conduit-1.3.6.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/conduit-1.3.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-conduit
hs-libraries:         HSconduit-1.3.6.1-8EwOhhDv3r5EX0bCaWMPRW
depends:
    base-4.17.2.1 bytestring-0.11.5.3 directory-1.3.7.1
    exceptions-0.10.5 filepath-1.4.2.2
    mono-traversable-1.0.21.0-5Xj4PzNQvkB2MFQ1sW1UM9 mtl-2.2.2
    primitive-0.9.1.0-ICFc9Oc8RCqLS4oNEzcX43
    resourcet-1.2.6-1DDiq5XD7CWDw9CwnQya4j text-2.0.2
    transformers-0.5.6.2 unix-2.7.3
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    vector-0.13.2.0-JDMr93x2QgFDQPvksTJZzq

haddock-interfaces:   /usr/share/doc/haskell-conduit/html/conduit.haddock
haddock-html:         /usr/share/doc/haskell-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
